@@ -15,9 +15,10 @@ class UserSerializer(serializers.ModelSerializer):
 
 
 class NotificationSerializer(serializers.HyperlinkedModelSerializer):
+    regex = serializers.CharField(source='display_only_if_url_path_matches_regex')
     class Meta:
         model = Notification
-        fields = ('name', 'message', 'snooze_time', 'snooze_lock', 'look', 'image', )
+        fields = ('name', 'message', 'snooze_time', 'snooze_lock', 'look', 'image', 'regex',)
 
 
 class UserNotificationSerializer(serializers.HyperlinkedModelSerializer):
